Learn R Programming

hlaR (version 1.0.0)

EvalAlleleMism: Evaluate mismatched alleles

Description

Compare donor and recipient HLA(Human Leukocyte Antigen) typing data to determine mismatched alleles. Input data can be high or low resolution, mismatch is evaluated at the allele level.

Usage

EvalAlleleMism(don_1, don_2, recip_1, recip_2, hmz_cnt = 1)

Value

A data frame of original input columns followed by mism_cnt of each donor/recipient pair.

Arguments

don_1

Donor's alpha1 domain.

don_2

Donor's alpha2 or beta1 domain.

recip_1

Recipient's alpha1 domain.

recip_2

Recipient's alpha2 or beta1 domain.

hmz_cnt

Use hmz_cnt to determine how mismatch at homozygous alleles should be handled. By default, a mismatch at a homozygous allele is considered a single mismatch. Set hmz_cnt = 2 to count homozygous mismatches as double.

Examples

Run this code
dat <- read.csv(system.file("extdata/example", "HLA_Clean_test.csv", package = "hlaR"))
re <- EvalAlleleMism(dat$donor_a1, dat$donor_a2, dat$recipient_a1, dat$recipient_a2, hmz_cnt = 2)

Run the code above in your browser using DataLab