Learn R Programming

hlaR (version 1.0.0)

ImputeHaplo: Imputation

Description

Impute low or mixed resolution HLA(Human Leukocyte Antigen) typing to the most likely high resolution equivalent. Imputation is computationally intensive, so large dataset may encounter delays in processing. This function uses data from the NMDP(National Marrow Donor Program), and is currently limited to HLA A, B, C, and DRB loci.

Usage

ImputeHaplo(dat_in)

Value

A data frame with high resolution HLA data pulled from the most likely pair of haplotypes matching the input low resolution data.

Arguments

dat_in

A data frame with low resolution HLA data.

Examples

Run this code
# \donttest{
dat <- read.csv(system.file("extdata/example", "Haplotype_test.csv", package = "hlaR"))
result <- ImputeHaplo(dat_in = dat[c(1:2), ])
# }

Run the code above in your browser using DataLab